# Topsis 
## A Multi-Criteria Decision Analysis Method

**Submitted By** - Shikhar Saini 
**Roll No.** - 102083055
**Group** - 3CO5

It is a Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) came in the 1980s as a multi-criteria-based decision-making method. TOPSIS chooses the alternative of shortest the Euclidean distance from the ideal solution and greatest distance from the negative ideal solution. 

## Installation
This package requires pandas to be pre-installed and python to run.
Install the dependencies and devDependencies and start the server.
 **To Install and run in cmd line:**
```sh
pip install Topsis-Shikhar-102083055
import Topsis_Shikhar_102083055
Topsis_Shikhar_102083055.Topsis(Input_File_Name.csv,"1,1,1,1 ...","+,-,+,- ...","resultfile.csv") 
```
